# Changelog

## 1.0.8 - 2021-01-18
* Improve error handling with bad credentials files


## 1.0.7 - 2020-10-28
* Change to MIT license

## 1.0.6 - 2020-09-23
* Pass client library name and version to server
* Added AAD information to ciphers for encrypt and decrypT

## 1.0.5 - 2020-08-25
* Added support for AES-128-GCM

## 1.0.4 - 2020-08-23
* Remove port number from default URL for api.ubiqsecurity.com

## 1.0.0 - 2020-08-05
* Initial Version
